/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-  */
/* 
 * Copyright (C) 2019 by Giam Teck Choon
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/*!
 *  @file is_dir.c
 *  @date 21 Sep 2019
 *  @author Giam Teck Choon
 *  @brief Function for is_dir()
 *  @bug No known bugs.
 */

#include <sys/types.h> /* for stat() */
#include <sys/stat.h> /* for stat() */
#include <unistd.h> /* for stat() */

/*!
 *  @brief Tell whether the given path is a directory.
 *  @param path Path to the directory. If path is a relative directory, it
 *              will be checked relative to the current working directory.
 *  @return On success, 1 is returned. Otherwise, 0 is returned.
 */
int is_dir(const char *path)
{
	static struct stat st;
	if (stat(path, &st) == 0 && S_ISDIR(st.st_mode))
		return 1;
	return 0;
}
