/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-  */
/* 
 * Copyright (C) 2019 by Giam Teck Choon
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/*!
 *  @file str_random.c
 *  @date 21 Sep 2019
 *  @author Giam Teck Choon
 *  @brief Function for str_random()
 *  @bug No known bugs.
 */

#include <stdlib.h>
#include <string.h>
#include <sys/time.h>
#include <errno.h>
#include <bglibs/str.h>

/*!
 *  @brief Generate random string according to specify length.
 *  @param s Record random string to struct str s.
 *  @param len Length of random string to be generated.
 *  @return On success, 0 is returned. On error, -1 is returned, and errno
 *          is set appropriately.
 */
int str_random(str *s, size_t len)
{
	struct timeval t1;
	int r;
	r = gettimeofday(&t1, NULL); /* <sys/time.h> */
	if (r != 0) {
		return r;
	}
	srand(t1.tv_usec * t1.tv_sec + len); /* <stdlib.h> */
	static const char charset[] = "0123456789"
				      "abcdefghijklmnopqrstuvwxyz"
				      "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
	unsigned int nchars = strlen(charset); /* <string.h> */
	if (s->s) {
		if (!str_truncate(s, 0)) {
			errno = ENOMEM;
			return -1;
		}
	}
	size_t i;
	for (i=0; i<len; i++) {
		if (!str_catc(s, charset[(unsigned int) ((rand() /
			((double) RAND_MAX + 1)) * nchars)])) {
			errno = ENOMEM;
			return -1;
		}
	}
	if (s->len == len) {
		return 0;
	}
	errno = ENODATA;
	return -1;
}
