/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-  */
/* 
 * Copyright (C) 2019 by Giam Teck Choon
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/*!
 *  @file vpwlookup.c
 *  @date 21 Sep 2019
 *  @author Giam Teck Choon
 *  @brief Function for vpwlookup()
 *  @bug No known bugs.
 */

#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <errno.h>
#include <bglibs/str.h>
#include <bglibs/cdb.h>
#include <bglibs/vmailmgr/vpwentry.h>
#include "is_file.h"

/*!
 *  @brief Lookup virtual user of domain locally.
 *  @param vpw Record found user in struct vpwentry.
 *  @param user Virtual user string of domain.
 *  @param pwfile Path to the vmailmgr passwd.cdb.
 *  @return On success, 1 is returned otherwise 0 is returned. On error, -1 is
 *          returned, and errno is set appropriately.
 */
int vpwlookup(vpwentry *vpw, const char *user, const char *pwfile)
{
	if (!is_file(pwfile)) {
		errno = ENOENT;
		return -1;
	}
	int fd = open(pwfile, O_RDONLY);
	if (fd < 0) {
		return -1;
	}
	struct cdb c = {0};
	static str key = {0,0,0};
	static str data = {0,0,0};
	cdb_init(&c, fd);
	if (!str_copys(&key, user)) {
		errno = ENOMEM;
		return -1;
	}
	str_lower(&key);
	int rc = 0;
	if (cdb_get(&c, &key, &data) > 0) {
		if (vpwentry_import(vpw, &key, &data) > 0) {
			rc = 1;
		}
	}
	cdb_free(&c);
	str_free(&key);
	str_free(&data);
	close(fd);
	return rc;
}
